summaryrefslogtreecommitdiff
path: root/OvmfPkg/PlatformPei
diff options
context:
space:
mode:
authorMin M Xu <min.m.xu@intel.com>2022-11-07 15:50:11 +0800
committermergify[bot] <37929162+mergify[bot]@users.noreply.github.com>2022-11-14 04:55:34 +0000
commit765ba5bf050022de8c44d93e467639d7f5fa237c (patch)
tree595d6a78c26daaf6cd1cad617f21bd6d4a3fb431 /OvmfPkg/PlatformPei
parenta89f558d3c56d9c16e5f5b7d395c1aa36ccd38f2 (diff)
downloadedk2-765ba5bf050022de8c44d93e467639d7f5fa237c.zip
edk2-765ba5bf050022de8c44d93e467639d7f5fa237c.tar.gz
edk2-765ba5bf050022de8c44d93e467639d7f5fa237c.tar.bz2
OvmfPkg/UefiCpuPkg: Add CcExit prefix to the APIs of CcExitLib
BZ: https://bugzilla.tianocore.org/show_bug.cgi?id=4123 APIs which are defined in CcExitLib.h are added with the CcExit prefix. This is to make the APIs' name more meaningful. This change impacts OvmfPkg/UefiCpuPkg. Cc: Eric Dong <eric.dong@intel.com> Cc: Ray Ni <ray.ni@intel.com> Cc: Brijesh Singh <brijesh.singh@amd.com> Cc: Erdem Aktas <erdemaktas@google.com> Cc: Gerd Hoffmann <kraxel@redhat.com> Cc: James Bottomley <jejb@linux.ibm.com> Cc: Jiewen Yao <jiewen.yao@intel.com> Cc: Tom Lendacky <thomas.lendacky@amd.com> Reviewed-by: Jiewen Yao <jiewen.yao@intel.com> Reviewed-by: Ray Ni <ray.ni@intel.com> Signed-off-by: Min Xu <min.m.xu@intel.com>
Diffstat (limited to 'OvmfPkg/PlatformPei')
-rw-r--r--OvmfPkg/PlatformPei/AmdSev.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/OvmfPkg/PlatformPei/AmdSev.c b/OvmfPkg/PlatformPei/AmdSev.c
index 80a1194..e1b9fd9 100644
--- a/OvmfPkg/PlatformPei/AmdSev.c
+++ b/OvmfPkg/PlatformPei/AmdSev.c
@@ -50,7 +50,7 @@ AmdSevSnpInitialize (
}
//
// Query the hypervisor feature using the VmgExit and set the value in the
// hypervisor features PCD.
//
HvFeatures = GetHypervisorFeature ();
@@ -129,19 +129,19 @@ GetHypervisorFeature (
//
// Initialize the GHCB
//
- VmgInit (Ghcb, &InterruptState);
+ CcExitVmgInit (Ghcb, &InterruptState);
//
// Query the Hypervisor Features.
//
- Status = VmgExit (Ghcb, SVM_EXIT_HYPERVISOR_FEATURES, 0, 0);
+ Status = CcExitVmgExit (Ghcb, SVM_EXIT_HYPERVISOR_FEATURES, 0, 0);
if ((Status != 0)) {
SevEsProtocolFailure (GHCB_TERMINATE_GHCB_GENERAL);
}
Features = Ghcb->SaveArea.SwExitInfo2;
- VmgDone (Ghcb, InterruptState);
+ CcExitVmgDone (Ghcb, InterruptState);
return Features;
}
@@ -50,7 +50,7 @@ AmdSevSnpInitialize (
}
//
- // Query the hypervisor feature using the VmgExit and set the value in the
+ // Query the hypervisor feature using the CcExitVmgExit and set the value in the
// hypervisor features PCD.
//